"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createLogger = exports.padScope = exports.getLogLevel = exports.setLogLevel = void 0;
const signale_1 = require("signale");
const logLevels = ['silent', 'info', 'debug', 'trace'];
const LOG_LENGTH = 10;
let logLevel = 'info';
const options = {
    types: {
        debug: {
            badge: '🦄',
            color: 'magenta',
            label: 'debug'
        },
        skip: {
            badge: '🤷',
            color: 'yellow',
            label: 'Skipping...'
        },
        trace: {
            badge: '🔊',
            color: 'gray',
            label: 'trace'
        },
        info: {
            badge: '💾',
            color: 'cyan',
            label: 'info'
        },
        note: {
            badge: '📝',
            color: 'blueBright',
            label: 'note'
        },
        complete: {
            badge: '🌟',
            color: 'green',
            label: 'complete'
        },
        await: {
            badge: '⏳',
            color: 'cyan',
            label: 'awaiting'
        },
        done: {
            badge: '🎉',
            color: 'greenBright',
            label: 'done'
        },
        error: {
            badge: '🚒',
            color: 'red',
            label: 'error'
        },
        pending: {
            badge: '🤞',
            color: 'magenta',
            label: 'pending'
        }
    }
};
const logger = new signale_1.Signale(options);
/** Change the log level for the CLI. */
function setLogLevel(v) {
    logLevel = v;
}
exports.setLogLevel = setLogLevel;
/** Get the current log level for the CLI. */
function getLogLevel() {
    return logLevel;
}
exports.getLogLevel = getLogLevel;
/** Pad the scope string to our default length. */
function padScope(s, size = LOG_LENGTH) {
    if (s.length === size) {
        return s;
    }
    if (s.length > size) {
        return `${s.substr(0, size - 3)}...`;
    }
    if (s.length < size) {
        return `${s}${'.'.repeat(size - s.length)}`;
    }
    return s;
}
exports.padScope = padScope;
/** Only call a function if the verbosity is high enough. */
function callIfVerbose(level, fn, ...args) {
    if (logLevels.indexOf(logLevel) >= logLevels.indexOf(level)) {
        return fn(...args);
    }
}
/** Create a logger scoped to a specific command. */
function createLogger({ scope, interactive }) {
    const scoped = interactive && logLevel !== 'trace' && logLevel !== 'debug'
        ? new signale_1.Signale(Object.assign({ interactive: true, scope }, options))
        : logger.scope(padScope(scope));
    const { trace, skip, debug } = scoped;
    if (logLevel === 'silent') {
        scoped.disable();
    }
    /** Conditionally call the trace logger */
    scoped.trace = (...args) => callIfVerbose('trace', trace, ...args);
    /** Conditionally call the skip logger */
    scoped.skip = (...args) => callIfVerbose('trace', skip, ...args);
    /** Conditionally call the debug logger */
    scoped.debug = (...args) => callIfVerbose('debug', debug, ...args);
    return scoped;
}
exports.createLogger = createLogger;
//# sourceMappingURL=create-logger.js.map